==> networkmanager-qt-5.55.0.tar.xz: networkmanager-qt-5.55.0/src/settings/proxysetting.h <==
/*
    Copyright 2018 Pranav Gade <pranavgade20@gmail.com>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef NETWORKMANAGERQT_PROXY_SETTING_H
#define NETWORKMANAGERQT_PROXY_SETTING_H

#include <networkmanagerqt/networkmanagerqt_export.h>
#include "setting.h"

#include <QString>

namespace NetworkManager
{

class ProxySettingPrivate;

/**
 * Represents proxy setting
 */
class NETWORKMANAGERQT_EXPORT ProxySetting : public Setting
{
public:
    typedef QSharedPointer<ProxySetting> Ptr;
    typedef QList<Ptr> List;
    enum Mode {
        None = 0,
        Auto = 1
    };

    ProxySetting();
    explicit ProxySetting(const Ptr &other);
    ~ProxySetting() override;

    QString name() const override;

    void setBrowserOnly(bool browserOnly);
    bool browserOnly() const;

    void setMethod(Mode method);
    Mode method() const;

    void setPacScript(const QString &script);
    QString pacScript() const;

    void setPacUrl(const QString &url);
    QString pacUrl() const;

    void fromMap(const QVariantMap &setting) override;

    QVariantMap toMap() const override;

protected:
    ProxySettingPrivate *d_ptr;

private:
    Q_DECLARE_PRIVATE(ProxySetting)
};

NETWORKMANAGERQT_EXPORT QDebug operator<<(QDebug dbg, const ProxySetting &setting);

}

#endif // NETWORKMANAGERQT_PROXY_SETTING_H

==> networkmanager-qt-6.18.0.tar.xz: networkmanager-qt-6.18.0/src/settings/proxysetting.h <==
/*
    SPDX-FileCopyrightText: 2018 Pranav Gade <pranavgade20@gmail.com>

    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
*/

#ifndef NETWORKMANAGERQT_PROXY_SETTING_H
#define NETWORKMANAGERQT_PROXY_SETTING_H

#include "setting.h"
#include <networkmanagerqt/networkmanagerqt_export.h>

#include <QString>

namespace NetworkManager
{
class ProxySettingPrivate;

/*!
 * \class NetworkManager::ProxySetting
 * \inheaderfile NetworkManagerQt/ProxySetting
 * \inmodule NetworkManagerQt
 *
 * \brief Represents proxy setting.
 */
class NETWORKMANAGERQT_EXPORT ProxySetting : public Setting
{
public:
    /*!
     * \typedef NetworkManager::ProxySetting::Ptr
     */
    typedef QSharedPointer<ProxySetting> Ptr;
    /*!
     * \typedef NetworkManager::ProxySetting::List
     */
    typedef QList<Ptr> List;
    /*!
     *
     * \value None
     * \value Auto
     */
    enum Mode {
        None = 0,
        Auto = 1,
    };

    /*!
     */
    ProxySetting();
    /*!
     */
    explicit ProxySetting(const Ptr &other);
    ~ProxySetting() override;

    QString name() const override;

    /*!
     */
    void setBrowserOnly(bool browserOnly);
    /*!
     */
    bool browserOnly() const;

    /*!
     */
    void setMethod(Mode method);
    /*!
     */
    Mode method() const;

    /*!
     */
    void setPacScript(const QString &script);
    /*!
     */
    QString pacScript() const;

    /*!
     */
    void setPacUrl(const QString &url);
    /*!
     */
    QString pacUrl() const;

    void fromMap(const QVariantMap &setting) override;

    QVariantMap toMap() const override;

protected:
    ProxySettingPrivate *d_ptr;

private:
    Q_DECLARE_PRIVATE(ProxySetting)
};

NETWORKMANAGERQT_EXPORT QDebug operator<<(QDebug dbg, const ProxySetting &setting);

}

#endif // NETWORKMANAGERQT_PROXY_SETTING_H
